@@ -2,9 +2,11 @@
 Replace compatibility imports for django.core.exceptions.EmptyResultSet:
 https://docs.djangoproject.com/en/3.1/releases/3.1/#id1
 """
+from __future__ import annotations
+
 import ast
 from functools import partial
-from typing import Iterable, Tuple
+from typing import Iterable
 
 from tokenize_rt import Offset
 
@@ -30,7 +32,7 @@ def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
     parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         node.module in REWRITES
         and is_rewritable_import_from(node)
