@@ -2,10 +2,11 @@
 Replace declarations of database support in test cases:
 https://docs.djangoproject.com/en/2.2/releases/2.2/#features-deprecated-in-2-2
 """
+from __future__ import annotations
+
 import ast
-import re
 from functools import partial
-from typing import Iterable, List, Tuple
+from typing import Iterable
 
 from tokenize_rt import Offset, Token
 
@@ -19,19 +20,12 @@ fixer = Fixer(
 )
 
 
-test_re = re.compile(r"(\b|_)tests?(\b|_)")
-
-
-def looks_like_test_file(filename: str) -> bool:
-    return test_re.search(filename) is not None
-
-
 @fixer.register(ast.Assign)
 def visit_Assign(
     state: State,
     node: ast.Assign,
     parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         isinstance(parent, ast.ClassDef)
         and len(node.targets) == 1
@@ -39,7 +33,7 @@ def visit_Assign(
         and node.targets[0].id in ("allow_database_queries", "multi_db")
         and isinstance(node.value, ast.Constant)
         and (node.value.value is True or node.value.value is False)
-        and looks_like_test_file(state.filename)
+        and state.looks_like_test_file()
     ):
         yield ast_start_offset(node), partial(
             replace_assignment, node=node, value=node.value.value
@@ -47,7 +41,7 @@ def visit_Assign(
 
 
 def replace_assignment(
-    tokens: List[Token], i: int, *, node: ast.Assign, value: bool
+    tokens: list[Token], i: int, *, node: ast.Assign, value: bool
 ) -> None:
     print("???", value)
     new_src = "databases = "
